@@ -23,7 +23,8 @@ class GtkUI(InstallerUI):
         self._app: Adw.Application | None = None
 
     def init(self) -> None:
-        pass
+        self._app = Adw.Application(application_id="org.edubuntu.Installer")
+        self._app.register()
 
     def quit(self) -> None:
         pass
@@ -55,8 +56,7 @@ class GtkUI(InstallerUI):
                 dlg.add_response(str(resp_id), label)
         return dlg
 
-    @staticmethod
-    def _run_adw_dialog(dlg: Adw.MessageDialog) -> str:
+    def _run_adw_dialog(self, dlg: Adw.MessageDialog) -> str:
         loop = GLib.MainLoop()
         result = {"response": "cancel"}
 
@@ -65,6 +65,8 @@ class GtkUI(InstallerUI):
             loop.quit()
 
         dlg.connect("response", on_response)
+        if self._app:
+            dlg.set_application(self._app)
         dlg.present()
         loop.run()
         return result["response"]
@@ -120,6 +122,8 @@ class GtkUI(InstallerUI):
         box = Gtk.Box(orientation=Gtk.Orientation.VERTICAL, spacing=12)
         box.set_margin_start(12)
         box.set_margin_end(12)
+        box.set_margin_top(12)
+        box.set_margin_bottom(12)
 
         label = Gtk.Label(label=text, wrap=True, use_markup=True)
         label.set_xalign(0)
@@ -158,6 +162,8 @@ class GtkUI(InstallerUI):
         box = Gtk.Box(orientation=Gtk.Orientation.VERTICAL, spacing=12)
         box.set_margin_start(12)
         box.set_margin_end(12)
+        box.set_margin_top(12)
+        box.set_margin_bottom(12)
 
         label = Gtk.Label(label=text, wrap=True, use_markup=True)
         label.set_xalign(0)
@@ -213,10 +219,14 @@ class GtkUI(InstallerUI):
             modal=True,
         )
         dlg.set_body_use_markup(True)
+        if width > 0:
+            dlg.set_default_size(width, max(height, 400))
 
         box = Gtk.Box(orientation=Gtk.Orientation.VERTICAL, spacing=8)
         box.set_margin_start(12)
         box.set_margin_end(12)
+        box.set_margin_top(12)
+        box.set_margin_bottom(12)
 
         info_label = Gtk.Label(label=text, wrap=True, use_markup=True)
         info_label.set_xalign(0)
@@ -267,10 +277,14 @@ class GtkUI(InstallerUI):
             modal=True,
         )
         dlg.set_body_use_markup(True)
+        if width > 0:
+            dlg.set_default_size(width, max(height, 400))
 
         box = Gtk.Box(orientation=Gtk.Orientation.VERTICAL, spacing=8)
         box.set_margin_start(12)
         box.set_margin_end(12)
+        box.set_margin_top(12)
+        box.set_margin_bottom(12)
 
         info_label = Gtk.Label(label=text, wrap=True, use_markup=True)
         info_label.set_xalign(0)
@@ -333,13 +347,16 @@ class GtkUI(InstallerUI):
             modal=True,
         )
         dlg.set_body_use_markup(True)
+        if width > 0:
+            dlg.set_default_size(width, max(height, 400))
 
         notebook = Gtk.Notebook()
 
         pkg_box = Gtk.Box(orientation=Gtk.Orientation.VERTICAL, spacing=8)
         pkg_box.set_margin_start(12)
         pkg_box.set_margin_end(12)
-        pkg_box.set_margin_top(8)
+        pkg_box.set_margin_top(12)
+        pkg_box.set_margin_bottom(12)
 
         pkg_label = Gtk.Label(label=pkg_text, wrap=True, use_markup=True)
         pkg_label.set_xalign(0)
@@ -361,7 +378,7 @@ class GtkUI(InstallerUI):
             pkg_checks.append((item.key, cb))
 
         pkg_scroll = Gtk.ScrolledWindow(hscrollbar_policy=Gtk.PolicyType.NEVER)
-        pkg_scroll.set_min_content_width(max(width - 80, 700))
+        pkg_scroll.set_min_content_width(max(width - 80, 850))
         pkg_scroll.set_min_content_height(max(height - 200, 200))
         pkg_scroll.set_child(pkg_box)
         notebook.append_page(pkg_scroll, Gtk.Label(label=_("Packages")))
@@ -369,7 +386,8 @@ class GtkUI(InstallerUI):
         setup_box = Gtk.Box(orientation=Gtk.Orientation.VERTICAL, spacing=12)
         setup_box.set_margin_start(12)
         setup_box.set_margin_end(12)
-        setup_box.set_margin_top(8)
+        setup_box.set_margin_top(12)
+        setup_box.set_margin_bottom(12)
 
         g_frame = Gtk.Frame(label=global_setup_text)
         g_inner = Gtk.Box(orientation=Gtk.Orientation.VERTICAL, spacing=4)
@@ -437,6 +455,7 @@ class GtkUI(InstallerUI):
                 if uname:
                     selected_user[0] = uname
                     _set_user_radios(uname)
+                    _check_changes()
 
             combo.connect("changed", _on_user_changed)
         else:
@@ -451,7 +470,7 @@ class GtkUI(InstallerUI):
         setup_scroll = Gtk.ScrolledWindow(
             hscrollbar_policy=Gtk.PolicyType.NEVER,
         )
-        setup_scroll.set_min_content_width(max(width - 80, 700))
+        setup_scroll.set_min_content_width(max(width - 80, 850))
         setup_scroll.set_min_content_height(max(height - 200, 200))
         setup_scroll.set_child(setup_box)
         notebook.append_page(setup_scroll, Gtk.Label(label=_("Default Setup")))
@@ -461,6 +480,40 @@ class GtkUI(InstallerUI):
         dlg.add_response("ok", ok_label)
         dlg.set_default_response("ok")
         dlg.set_close_response("cancel")
+        dlg.set_response_enabled("ok", False)
+
+        initial_pkgs = {item.key for item in pkg_items if item.checked}
+        initial_g_choice = ""
+        for item in global_setup_items:
+            if item.checked:
+                initial_g_choice = item.key
+                break
+        initial_u_choices: dict[str, str] = {
+            u: user_default_fn(u) for u in usernames
+        } if usernames else {}
+
+        def _check_changes() -> None:
+            current_pkgs = {key for key, cb in pkg_checks if cb.get_active()}
+            changed = current_pkgs != initial_pkgs
+            if not changed:
+                for key, rb in g_radios:
+                    if rb.get_active():
+                        changed = key != initial_g_choice
+                        break
+            if not changed and u_radios:
+                uname = selected_user[0]
+                for key, rb in u_radios:
+                    if rb.get_active():
+                        changed = key != initial_u_choices.get(uname, "")
+                        break
+            dlg.set_response_enabled("ok", changed)
+
+        for _key, cb in pkg_checks:
+            cb.connect("toggled", lambda _w: _check_changes())
+        for _key, rb in g_radios:
+            rb.connect("toggled", lambda _w: _check_changes())
+        for _key, rb in u_radios:
+            rb.connect("toggled", lambda _w: _check_changes())
 
         resp = self._run_adw_dialog(dlg)
         if resp == "ok":
@@ -499,6 +552,8 @@ class GtkUI(InstallerUI):
         outer = Gtk.Box(orientation=Gtk.Orientation.VERTICAL, spacing=8)
         outer.set_margin_start(12)
         outer.set_margin_end(12)
+        outer.set_margin_top(12)
+        outer.set_margin_bottom(12)
 
         progress = Gtk.ProgressBar()
         progress.set_show_text(False)
@@ -582,6 +637,8 @@ class GtkUI(InstallerUI):
             return False
 
         threading.Thread(target=worker, daemon=True).start()
+        if self._app:
+            dlg.set_application(self._app)
         dlg.present()
         loop.run()
         return success["value"]
