@@ -14,6 +14,7 @@ from PyQt6.QtWidgets import (
     QComboBox,
     QDialog,
     QDialogButtonBox,
+    QFrame,
     QGroupBox,
     QHBoxLayout,
     QInputDialog,
@@ -58,7 +59,7 @@ def _wrapping_row(button: QCheckBox | QRadioButton, text: str) -> QWidget:
     label.mousePressEvent = lambda _ev: button.toggle()
     row = QWidget()
     h = QHBoxLayout(row)
-    h.setContentsMargins(0, 0, 0, 0)
+    h.setContentsMargins(4, 3, 4, 3)
     h.addWidget(button)
     h.addWidget(label, 1)
     return row
@@ -160,6 +161,8 @@ class QtUI(InstallerUI):
         dlg.setWindowIcon(QIcon(ICON_PATH))
 
         layout = QVBoxLayout(dlg)
+        layout.setSpacing(10)
+        layout.setContentsMargins(12, 12, 12, 12)
         info = QLabel(text)
         info.setWordWrap(True)
         layout.addWidget(info)
@@ -203,14 +206,19 @@ class QtUI(InstallerUI):
         dlg.setWindowIcon(QIcon(ICON_PATH))
 
         layout = QVBoxLayout(dlg)
+        layout.setSpacing(10)
+        layout.setContentsMargins(12, 12, 12, 12)
         info = QLabel(text)
         info.setWordWrap(True)
         layout.addWidget(info)
 
         scroll = QScrollArea()
         scroll.setWidgetResizable(True)
+        scroll.setFrameShape(QFrame.Shape.NoFrame)
         container = QWidget()
         vbox = QVBoxLayout(container)
+        vbox.setSpacing(2)
+        vbox.setContentsMargins(4, 4, 4, 4)
 
         checks: list[tuple[str, QCheckBox]] = []
         for item in items:
@@ -250,14 +258,19 @@ class QtUI(InstallerUI):
         dlg.setWindowIcon(QIcon(ICON_PATH))
 
         layout = QVBoxLayout(dlg)
+        layout.setSpacing(10)
+        layout.setContentsMargins(12, 12, 12, 12)
         info = QLabel(text)
         info.setWordWrap(True)
         layout.addWidget(info)
 
         scroll = QScrollArea()
         scroll.setWidgetResizable(True)
+        scroll.setFrameShape(QFrame.Shape.NoFrame)
         container = QWidget()
         vbox = QVBoxLayout(container)
+        vbox.setSpacing(2)
+        vbox.setContentsMargins(4, 4, 4, 4)
 
         group = QButtonGroup(dlg)
         radios: list[tuple[str, QRadioButton]] = []
@@ -306,10 +319,13 @@ class QtUI(InstallerUI):
         dlg.setWindowIcon(QIcon(ICON_PATH))
 
         outer = QVBoxLayout(dlg)
+        outer.setSpacing(10)
+        outer.setContentsMargins(12, 12, 12, 12)
         tabs = QTabWidget()
 
         pkg_page = QWidget()
         pkg_layout = QVBoxLayout(pkg_page)
+        pkg_layout.setSpacing(10)
 
         pkg_label = QLabel(pkg_text)
         pkg_label.setWordWrap(True)
@@ -317,8 +333,11 @@ class QtUI(InstallerUI):
 
         pkg_scroll = QScrollArea()
         pkg_scroll.setWidgetResizable(True)
+        pkg_scroll.setFrameShape(QFrame.Shape.NoFrame)
         pkg_container = QWidget()
         pkg_vbox = QVBoxLayout(pkg_container)
+        pkg_vbox.setSpacing(2)
+        pkg_vbox.setContentsMargins(4, 4, 4, 4)
 
         pkg_checks: list[tuple[str, QCheckBox]] = []
         for item in pkg_items:
@@ -472,6 +491,8 @@ class QtUI(InstallerUI):
         dlg.setMinimumWidth(500)
 
         layout = QVBoxLayout(dlg)
+        layout.setSpacing(10)
+        layout.setContentsMargins(12, 12, 12, 12)
 
         label = QLabel(text)
         label.setWordWrap(True)
